permission_master library
Classes
- GetStorageBridge
- A bridge class to interact with the native storage methods using MethodChannel. Example usage:
- PermissionMaster
- A class to manage and request permissions in a Flutter application.
Enums
- PermissionStatus
- Enum to represent the status of a permission request.
- PermissionType
- PermissionTypeLinux
- PermissionTypeMacOS
- PermissionTypeWeb
- PermissionTypeWindows