PermissionTypeMacOS enum

Inheritance
Available extensions

Values

camera → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.CAMERA')
microphone → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.MICROPHONE')
location → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.LOCATION')
photos → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.PHOTOS')
contacts → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.CONTACTS')
notification → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.NOTIFICATION')
bluetooth → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.BLUETOOTH')
calendar → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.CALENDAR')
reminders → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.REMINDERS')
speech → const PermissionTypeMacOS
const PermissionTypeMacOS('macos.permission.SPEECH')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionTypeMacOS>
A constant List of the values in this enum, in order of their declaration.