PermissionTypeWindows enum
Values
- camera → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.CAMERA') - microphone → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.MICROPHONE') - location → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.LOCATION') - storage → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.STORAGE') - contacts → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.CONTACTS') - calendar → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.CALENDAR') - notifications → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.NOTIFICATIONS') - radios → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.RADIOS') - voiceActivation → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.VOICE_ACTIVATION') - email → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.EMAIL') - speech → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.SPEECH') - bluetooth → const PermissionTypeWindows
-
const PermissionTypeWindows('windows.permission.BLUETOOTH')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PermissionTypeWindows> - A constant List of the values in this enum, in order of their declaration.